pecos.simulators.paulifaultprop.gates\_meas
===========================================

.. automodule:: pecos.simulators.paulifaultprop.gates_meas







   .. rubric:: Functions

   .. autosummary::

      force_output
      meas_pauli
      meas_x
      meas_y
      meas_z
